pub fn py_logging_sync_to_disk() -> PyResult<bool>Expand description
Flushes and syncs file logs to disk.
This is a no-op when logging is not initialized or file logging is disabled.
Errors
Returns an error if the sync request cannot be delivered or acknowledged.